summaryrefslogtreecommitdiffstats
path: root/lib/kofficecore/KoDocumentChild.h
diff options
context:
space:
mode:
Diffstat (limited to 'lib/kofficecore/KoDocumentChild.h')
-rw-r--r--lib/kofficecore/KoDocumentChild.h12
1 files changed, 6 insertions, 6 deletions
diff --git a/lib/kofficecore/KoDocumentChild.h b/lib/kofficecore/KoDocumentChild.h
index 491f9b2d..de3704c0 100644
--- a/lib/kofficecore/KoDocumentChild.h
+++ b/lib/kofficecore/KoDocumentChild.h
@@ -45,19 +45,19 @@ class KOFFICECORE_EXPORT KoDocumentChild : public KoChild
Q_OBJECT
TQ_OBJECT
public:
- KoDocumentChild( KoDocument* tqparent, KoDocument* doc, const TQRect& tqgeometry );
+ KoDocumentChild( KoDocument* parent, KoDocument* doc, const TQRect& tqgeometry );
/**
* When using this constructor you must call @ref #setDocument before
* you can call any other function of this class.
*/
- KoDocumentChild( KoDocument* tqparent );
+ KoDocumentChild( KoDocument* parent );
virtual ~KoDocumentChild();
/**
* Call this function only directly after calling the constructor
* that takes only a tqparent as argument.
*/
virtual void setDocument( KoDocument *doc, const TQRect &tqgeometry );
@@ -69,7 +69,7 @@ public:
KoDocument *document() const;
/**
* @return tqparent document of this child
*
* @see KoDocument
*/
@@ -98,7 +98,7 @@ public:
/**
* Save an embedded object to OASIS.
* This method sets the attributes for the draw:object element in the tqparent XML document.
* It also prepares the embedded object for being saved into the store at
* the end of saving (see saveOasisToStore).
* Note that @p name is only used for "internal" documents (not extern).
@@ -107,7 +107,7 @@ public:
/**
* Save an embedded object to an OASIS store.
* This is called automatically by the tqparent KoDocument's saveOasis
*/
virtual bool saveOasis( KoStore* store, KoXmlWriter* manifestWriter );
@@ -45,19 +45,19 @@ class KOFFICECORE_EXPORT KoDocumentChild : public KoChild
/**
* Call this function only directly after calling the constructor
- * that takes only a tqparent as argument.
+ * that takes only a parent as argument.
*/
virtual void setDocument( KoDocument *doc, const TQRect &tqgeometry );
@@ -69,7 +69,7 @@ public:
KoDocument *document() const;
/**
- * @return tqparent document of this child
+ * @return parent document of this child
*
* @see KoDocument
@@ -98,7 +98,7 @@ public:
/**
* Save an embedded object to OASIS.
- * This method sets the attributes for the draw:object element in the tqparent XML document.
+ * This method sets the attributes for the draw:object element in the parent XML document.
* It also prepares the embedded object for being saved into the store at
* the end of saving (see saveOasisToStore).
@@ -107,7 +107,7 @@ public:
/**
* Save an embedded object to an OASIS store.
- * This is called automatically by the tqparent KoDocument's saveOasis
+ * This is called automatically by the parent KoDocument's saveOasis
*/
virtual bool saveOasis( KoStore* store, KoXmlWriter* manifestWriter );